==> activity-custom-center-api-0.3.51-sources.jar: cn/com/duiba/activity/custom/center/api/params/hsbc/HsbcCurrentGearParam.java <==
package cn.com.duiba.activity.custom.center.api.params.hsbc;

import java.io.Serializable;
import java.util.Date;

/**
 *
 * @author fss
 */
public class HsbcCurrentGearParam implements Serializable {

    private static final long serialVersionUID = 631984599002131917L;

    private Long appId;

    private Long consumerId;

    /**
     * 档位唯一ID;档位金额;档位限制范围;
     */
    private String gearDimension;

    /**
     * 档位重新计算修改时间戳
     */
    private Long changeTimestamp;

    /**
     * 开始时间
     */
    private Date startDate;

    /**
     * 结束时间
     */
    private Date endDate;

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public String getGearDimension() {
        return gearDimension;
    }

    public void setGearDimension(String gearDimension) {
        this.gearDimension = gearDimension;
    }

    public Long getChangeTimestamp() {
        return changeTimestamp;
    }

    public void setChangeTimestamp(Long changeTimestamp) {
        this.changeTimestamp = changeTimestamp;
    }

    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }
}

==> activity-custom-center-api-1.0.11-sources.jar: cn/com/duiba/activity/custom/center/api/params/hsbc/HsbcCurrentGearParam.java <==
package cn.com.duiba.activity.custom.center.api.params.hsbc;

import java.io.Serializable;
import java.util.Date;
import java.util.Objects;

/**
 *
 * @author fss
 */
public class HsbcCurrentGearParam implements Serializable {

    private static final long serialVersionUID = 631984599002131917L;

    private Long appId;

    private Long consumerId;

    /**
     * 档位唯一ID;档位金额;档位限制范围;
     */
    private String gearDimension;

    /**
     * 时间段唯一ID；时间段；变更时间戳
     */
    private String timeDimension;

    /**
     * 档位重新计算修改时间戳
     */
    private Long changeTimestamp;

    /**
     * 开始时间
     */
    private Date startDate;

    /**
     * 结束时间
     */
    private Date endDate;

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public String getGearDimension() {
        return gearDimension;
    }

    public void setGearDimension(String gearDimension) {
        this.gearDimension = gearDimension;
    }

    public String getTimeDimension() {
        return timeDimension;
    }

    public void setTimeDimension(String timeDimension) {
        this.timeDimension = timeDimension;
    }

    public Long getChangeTimestamp() {
        return changeTimestamp;
    }

    public void setChangeTimestamp(Long changeTimestamp) {
        this.changeTimestamp = changeTimestamp;
    }

    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }
}
